@@ -8,7 +8,7 @@ from .seqs import take
 
 
 __all__ = ['empty', 'iteritems', 'join', 'merge',
-           'walk', 'walk_keys', 'walk_values', 'select', 'select_keys', 'select_values',
+           'walk', 'walk_keys', 'walk_values', 'select', 'select_keys', 'select_values', 'compact',
            'is_distinct', 'all', 'any', 'none', 'one', 'some',
            'zipdict', 'flip', 'project',
            'where', 'pluck', 'invoke']
@@ -38,8 +38,9 @@ def iteritems(coll):
 def join(colls):
     colls, colls_copy = tee(colls)
     it = iter(colls_copy)
-    dest = next(it, None)
-    if dest is None:
+    try:
+        dest = next(it)
+    except StopIteration:
         return None
     cls = dest.__class__
 
@@ -90,6 +91,15 @@ def select_keys(pred, coll):
 def select_values(pred, coll):
     return select(lambda (k, v): pred(v), coll)
 
+
+def compact(coll):
+    pred = lambda x: x is not None
+    if isinstance(coll, Mapping):
+        return select_values(pred, coll)
+    else:
+        return select(pred, coll)
+
+
 ### Content tests
 
 def is_distinct(coll):
