@@ -11,6 +11,8 @@ __all__ = ['re_iter', 're_all', 're_find', 're_finder', 're_test', 're_tester']
 def _make_getter(regex):
     if regex.groups == 0:
         return methodcaller('group')
+    elif regex.groups == 1 and regex.groupindex == {}:
+        return methodcaller('group', 1)
     elif regex.groupindex == {}:
         return methodcaller('groups')
     elif regex.groups == len(regex.groupindex):
@@ -43,6 +45,11 @@ def re_test(regex, s, flags=0):
 def re_finder(regex, flags=0):
     regex, getter = _prepare(regex, flags)
     return lambda s: iffy(getter)(regex.search(s))
+    # TODO: optimize compose() and use:
+    # from .funcs import compose
+    # return compose(iffy(getter), regex.search)
 
 def re_tester(regex, flags=0):
     return lambda s: bool(re.search(regex, s, flags))
+
+# TODO: re_allfinder? better name?
